@@ -76,6 +76,21 @@ impl DhcpOptions {
         }
         Some(false)
     }
+    /// clear all options
+    pub fn clear(&mut self) {
+        self.0.clear()
+    }
+    /// Returns `true` if there are no options
+    pub fn is_empty(&self) -> bool {
+        self.0.is_empty()
+    }
+    /// Retans only the elements specified by the predicate
+    pub fn retain<F>(&mut self, pred: F)
+    where
+        F: FnMut(&OptionCode, &mut DhcpOption) -> bool,
+    {
+        self.0.retain(pred)
+    }
 }
 
 impl Decodable for DhcpOptions {
@@ -639,11 +654,11 @@ impl Decodable for DhcpOption {
             }
             OptionCode::RootPath => {
                 let length = decoder.read_u8()?;
-                DomainName(decoder.read_string(length as usize)?)
+                RootPath(decoder.read_string(length as usize)?)
             }
             OptionCode::ExtensionsPath => {
                 let length = decoder.read_u8()?;
-                DomainName(decoder.read_string(length as usize)?)
+                ExtensionsPath(decoder.read_string(length as usize)?)
             }
             OptionCode::IpForwarding => {
                 let _ = decoder.read_u8()?;
@@ -715,7 +730,7 @@ impl Decodable for DhcpOption {
             }
             OptionCode::NISDomain => {
                 let length = decoder.read_u8()?;
-                DomainName(decoder.read_string(length as usize)?)
+                NISDomain(decoder.read_string(length as usize)?)
             }
             OptionCode::NIS => {
                 let length = decoder.read_u8()?;
